"""
The file is about providing functions
to verify the package description in
pyproject.toml or setup.py

:author: Julian M. Kleber
"""


def speak_veritas() -> None:
    """
    With this function, lia asks you about the details
    of your package.

    """
